==> 0.0.18.tar.gz: lib/logic/user_info_form_functions.dart <==
import 'dart:convert';
//import 'package:flutter_firebase_basic_tools/logic/payment_redirect_type.dart';
import 'package:flutter_firebase_basic_tools/models/abei_user.dart';
import 'package:flutter_firebase_basic_tools/logic/show_custom_dialog.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';
import 'package:flutter_firebase_basic_tools/models/payment_redirect_type.dart';
import 'package:shared_preferences/shared_preferences.dart';

class UserInfoFormFunctions {
  login({
    @required BuildContext context,
    @required GlobalKey<ScaffoldState> scaffoldKey,
    @required bool rememberMe,
    @required GlobalKey<FormState> loginFormKey,
    @required List<TextEditingController> inputControllers,
    @required SharedPreferences prefs,
  }) async {
    TextEditingController emailInputController = inputControllers[0];
    TextEditingController passwordInputController = inputControllers[1];

    if (loginFormKey.currentState.validate()) {
      await FirebaseAuth.instance
          .signInWithEmailAndPassword(
        email: emailInputController.text,
        password: passwordInputController.text,
      )
          .then((UserCredential value) async {
        print("value: " + value.user.toString());

        User user = value.user;

        var uid = user.uid;

        DocumentSnapshot firestoreUser =
        await FirebaseFirestore.instance.collection("users").doc(uid).get();

        if (value.user.emailVerified) {
          Map<String, dynamic> newMap = firestoreUser.data();

          newMap["birthday"] = newMap["birthday"].toString();

          prefs.setString("user_info", jsonEncode(newMap));

          if (rememberMe) {
            prefs.setString("email", value.user.email);
          }

          Navigator.pushNamedAndRemoveUntil(
              context, '/ /home', ModalRoute.withName('/'),
              arguments: AbeiUser(
                uid,
                firestoreUser.data()["firstname"],
                firestoreUser.data()["lastname"],
                user.email,
                firestoreUser.data()["birthday"].toString(),
                firestoreUser.data()["gender"],
                firestoreUser.data()["country"],
                PaymentRedirectType.none,
              ));

          emailInputController.clear();
          passwordInputController.clear();
        } else {
          emailVerification(
            context: context,
            user: value.user,
          );

          /*scaffoldKey.currentState.showSnackBar(SnackBar(
            content: Text("You haven't verified your email yet"),
            duration: Duration(seconds: 3),
          ));*/
        }
        return null;
      }).catchError((onError) {
        print(onError);

        scaffoldKey.currentState.showSnackBar(SnackBar(
          content: Text("The password or email are invalid"),
          duration: Duration(milliseconds: 1500),
        ));
      });
    }
  }

  register({
    @required BuildContext context,
    @required GlobalKey<ScaffoldState> scaffoldKey,
    @required bool acceptTerms,
    @required GlobalKey<FormState> registerFormKey,
    @required List<TextEditingController> inputControllers,
    @required DateTime selectedDate,
    @required String genderValue,
    @required String countryValue,
  }) {
    TextEditingController firstNameInputController = inputControllers[0];
    TextEditingController lastNameInputController = inputControllers[1];
    TextEditingController emailInputController = inputControllers[2];
    TextEditingController confirmEmailInputController = inputControllers[3];
    TextEditingController passwordInputController = inputControllers[4];
    TextEditingController confirmPasswordInputController = inputControllers[5];

    if (acceptTerms) {
      if (registerFormKey.currentState.validate()) {
        if (emailInputController.text == confirmEmailInputController.text) {
          if (passwordInputController.text ==
              confirmPasswordInputController.text) {
            FirebaseAuth.instance
                .createUserWithEmailAndPassword(
              email: emailInputController.text,
              password: passwordInputController.text,
            )
                .then((currentUser) async {
              FirebaseAuth.instance.signInWithEmailAndPassword(
                email: emailInputController.text,
                password: passwordInputController.text,
              );

              Timestamp birthdayTimestamp = Timestamp.fromDate(selectedDate);

              FirebaseFirestore.instance
                  .collection("users")
                  .doc(currentUser.user.uid)
                  .set({
                "firstname": firstNameInputController.text,
                "lastname": lastNameInputController.text,
                "birthday": birthdayTimestamp,
                "gender": genderValue,
                "country": countryValue,
              }).then((result) {
                Navigator.pushNamedAndRemoveUntil(
                    context, '/ /home', ModalRoute.withName('/'),
                    arguments: AbeiUser(
                      currentUser.user.uid,
                      firstNameInputController.text,
                      lastNameInputController.text,
                      emailInputController.text,
                      birthdayTimestamp.toString(),
                      genderValue,
                      countryValue,
                      PaymentRedirectType.none,
                    ));

                firstNameInputController.clear();
                lastNameInputController.clear();
                emailInputController.clear();
                confirmEmailInputController.clear();
                passwordInputController.clear();
                confirmPasswordInputController.clear();
              }).catchError((err) => print(err));

              try {
                await currentUser.user.sendEmailVerification();
                return currentUser.user.uid;
              } catch (e) {
                print(
                    "An error occured while trying to send email verification");
                print(e.message);
              }
              return currentUser;
            });
          } else {
            ShowCustomDialog().simple(context, "The passwords do not match");
          }
        } else {
          ShowCustomDialog().simple(context, "The emails do not match");
        }
      }
    } else {
      scaffoldKey.currentState.showSnackBar(SnackBar(
        content: Text("You need to accept the terms of use & privacy policy"),
        duration: Duration(seconds: 3),
      ));
    }
  }

  forgotPassword({
    @required BuildContext context,
    @required GlobalKey<FormState> forgotPasswordFormKey,
    @required TextEditingController emailInputController,
  }) async {
    if (forgotPasswordFormKey.currentState.validate()) {
      try {
        await FirebaseAuth.instance
            .sendPasswordResetEmail(email: emailInputController.text);
        Navigator.pushNamed(context, '/ /login');
      } catch (e) {
        print("An error occured while trying to send password reset email");
        print(e.message);
      }
    }
  }

  emailVerification({
    @required BuildContext context,
    @required User user,
  }) async {
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          title: Text("You haven't verified your email yet"),
          content: Text("Would you like to send an email verification again?"),
          actions: <Widget>[
            FlatButton(
              child: Text("Cancel"),
              onPressed: () {
                Navigator.of(context).pop();
              },
            ),
            FlatButton(
              child: Text("Accept"),
              onPressed: () async {
                await user.sendEmailVerification().then((value) {
                  Navigator.of(context).pop();
                });
              },
            ),
          ],
        );
      },
    );
  }

  updateUserEmail({
    @required BuildContext context,
    @required GlobalKey<ScaffoldState> scaffoldKey,
    @required GlobalKey<FormState> emailFormKey,
    @required List<TextEditingController> inputControllers,
    @required String userID,
    @required bool isEditingEmail,
    @required widgetParent,
  }) async {
    TextEditingController emailInputController = inputControllers[0];
    TextEditingController confirmEmailInputController = inputControllers[1];

    Navigator.of(context).pop();

    if (emailFormKey.currentState.validate()) {
      if (emailInputController.text == confirmEmailInputController.text) {
        User user = FirebaseAuth.instance.currentUser;

        /*user.reauthenticateWithCredential(EmailAuthProvider.getCredential(
            email: 'email', password: 'password'));*/

        user.updateEmail(emailInputController.text).then((value) {
          FirebaseFirestore.instance.collection("users").doc(userID).update({
            "email": emailInputController.text,
          }).then((result) async {
            try {
              await user.sendEmailVerification();
            } catch (e) {
              print("An error occured while trying to send email verification");
              print(e.message);
            }

            isEditingEmail = false;

            widgetParent.setState(() {});

            scaffoldKey.currentState.showSnackBar(SnackBar(
              content: Text("User info saved"),
              duration: Duration(seconds: 3),
            ));
          }).catchError((err) => print(err));
        });
      } else {
        ShowCustomDialog().simple(context, "The emails do not match");
      }
    }
  }

  updateUserPassword({
    @required BuildContext context,
    @required GlobalKey<ScaffoldState> scaffoldKey,
    @required GlobalKey<FormState> passwordFormKey,
    @required List<TextEditingController> inputControllers,
    @required String userID,
    @required bool isEditingPassword,
    @required widgetParent,
  }) async {
    TextEditingController passwordInputController = inputControllers[0];
    TextEditingController confirmPasswordInputController = inputControllers[1];

    Navigator.of(context).pop();

    if (passwordFormKey.currentState.validate()) {
      if (passwordInputController.text == confirmPasswordInputController.text) {
        User user = FirebaseAuth.instance.currentUser;

        user.updatePassword(passwordInputController.text).then((_) {
          print("Succesfull changed password");

          isEditingPassword = false;

          widgetParent.setState(() {});

          scaffoldKey.currentState.showSnackBar(SnackBar(
            content: Text("User info saved"),
            duration: Duration(seconds: 3),
          ));
        }).catchError((error) {
          print("Password can't be changed" + error.toString());
        });
      } else {
        ShowCustomDialog().simple(context, "The passwords do not match");
      }
    }
  }

  updateUserNameAndInfo({
    @required BuildContext context,
    @required GlobalKey<ScaffoldState> scaffoldKey,
    @required GlobalKey<FormState> nameAndInfoFormKey,
    @required List<TextEditingController> inputControllers,
    @required DateTime selectedDate,
    @required String genderValue,
    @required String countryValue,
    @required String userID,
    @required bool isEditingNameAndInfo,
    @required widgetParent,
  }) {
    TextEditingController firstNameInputController = inputControllers[0];
    TextEditingController lastNameInputController = inputControllers[1];

    Timestamp birthdayTimestamp = Timestamp.fromDate(selectedDate);

    Navigator.of(context).pop();

    if (nameAndInfoFormKey.currentState.validate()) {
      FirebaseFirestore.instance.collection("users").doc(userID).update({
        "firstname": firstNameInputController.text,
        "lastname": lastNameInputController.text,
        "birthday": birthdayTimestamp,
        "gender": genderValue,
        "country": countryValue,
      }).then((result) {
        isEditingNameAndInfo = false;

        widgetParent.setState(() {});

        scaffoldKey.currentState.showSnackBar(SnackBar(
          content: Text("User info saved"),
          duration: Duration(seconds: 3),
        ));
      }).catchError((err) => print(err));
    }
  }
}

==> 0.0.63.tar.gz: lib/logic/user_info_form_functions.dart <==
import 'dart:convert';
import 'package:flutter_firebase_basic_tools/models/abei_user.dart';
import 'package:flutter_firebase_basic_tools/logic/show_custom_dialog.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';
import 'package:flutter_firebase_basic_tools/models/payment_redirect_type.dart';
import 'package:shared_preferences/shared_preferences.dart';

class UserInfoFormFunctions {
  login({
    @required BuildContext context,
    @required GlobalKey<ScaffoldState> scaffoldKey,
    @required bool rememberMe,
    @required GlobalKey<FormState> loginFormKey,
    @required List<TextEditingController> inputControllers,
    @required SharedPreferences prefs,
  }) async {
    TextEditingController emailInputController = inputControllers[0];
    TextEditingController passwordInputController = inputControllers[1];

    if (loginFormKey.currentState.validate()) {
      await FirebaseAuth.instance
          .setPersistence(Persistence.LOCAL)
          .then((value) async {
        await FirebaseAuth.instance
            .signInWithEmailAndPassword(
          email: emailInputController.text,
          password: passwordInputController.text,
        )
            .then((UserCredential value) async {
          print("value: " + value.user.toString());

          User user = value.user;
          String uid = user.uid;

          DocumentSnapshot firestoreUser = await FirebaseFirestore.instance
              .collection("users")
              .doc(uid)
              .get();

          if (value.user.emailVerified) {
            Map<String, dynamic> newMap = firestoreUser.data();

            newMap["birthday"] = newMap["birthday"].toString();

            prefs.setString("user_info", jsonEncode(newMap));

            if (rememberMe) {
              prefs.setString("email", value.user.email);
            }

            Navigator.pushNamedAndRemoveUntil(
                context, '/ /home', ModalRoute.withName('/'),
                arguments: AbeiUser(
                  uid,
                  firestoreUser.data()["firstname"],
                  firestoreUser.data()["lastname"],
                  user.email,
                  firestoreUser.data()["birthday"].toString(),
                  firestoreUser.data()["gender"],
                  firestoreUser.data()["country"],
                  PaymentRedirectType.none,
                ));

            emailInputController.clear();
            passwordInputController.clear();
          } else {
            emailVerification(
              context: context,
              user: value.user,
            );
          }
          return null;
        }).catchError((onError) {
          print(onError);

          scaffoldKey.currentState.showSnackBar(SnackBar(
            content: Text("The password or email are invalid"),
            duration: Duration(milliseconds: 1500),
          ));
        });
      });
    }
  }

  register({
    @required BuildContext context,
    @required GlobalKey<ScaffoldState> scaffoldKey,
    @required bool acceptTerms,
    @required GlobalKey<FormState> registerFormKey,
    @required List<TextEditingController> inputControllers,
    @required DateTime selectedDate,
    @required String genderValue,
    @required String countryValue,
  }) {
    TextEditingController firstNameInputController = inputControllers[0];
    TextEditingController lastNameInputController = inputControllers[1];
    TextEditingController emailInputController = inputControllers[2];
    TextEditingController confirmEmailInputController = inputControllers[3];
    TextEditingController passwordInputController = inputControllers[4];
    TextEditingController confirmPasswordInputController = inputControllers[5];

    if (acceptTerms) {
      if (registerFormKey.currentState.validate()) {
        if (emailInputController.text == confirmEmailInputController.text) {
          if (passwordInputController.text ==
              confirmPasswordInputController.text) {
            FirebaseAuth.instance
                .createUserWithEmailAndPassword(
              email: emailInputController.text,
              password: passwordInputController.text,
            )
                .then((currentUser) async {
              FirebaseAuth.instance.signInWithEmailAndPassword(
                email: emailInputController.text,
                password: passwordInputController.text,
              );

              Timestamp birthdayTimestamp = Timestamp.fromDate(selectedDate);

              FirebaseFirestore.instance
                  .collection("users")
                  .doc(currentUser.user.uid)
                  .set({
                "firstname": firstNameInputController.text,
                "lastname": lastNameInputController.text,
                "birthday": birthdayTimestamp,
                "gender": genderValue,
                "country": countryValue,
              }).then((result) {
                Navigator.pushNamedAndRemoveUntil(
                    context, '/ /home', ModalRoute.withName('/'),
                    arguments: AbeiUser(
                      currentUser.user.uid,
                      firstNameInputController.text,
                      lastNameInputController.text,
                      emailInputController.text,
                      birthdayTimestamp.toString(),
                      genderValue,
                      countryValue,
                      PaymentRedirectType.none,
                    ));

                firstNameInputController.clear();
                lastNameInputController.clear();
                emailInputController.clear();
                confirmEmailInputController.clear();
                passwordInputController.clear();
                confirmPasswordInputController.clear();
              }).catchError((err) => print(err));

              try {
                await currentUser.user.sendEmailVerification();
                return currentUser.user.uid;
              } catch (e) {
                print(
                    "An error occured while trying to send email verification");
                print(e.message);
              }
              return currentUser;
            });
          } else {
            ShowCustomDialog().simple(
                context, "The passwords do not match", "Error", "Close");
          }
        } else {
          ShowCustomDialog()
              .simple(context, "The emails do not match", "Error", "Close");
        }
      }
    } else {
      scaffoldKey.currentState.showSnackBar(SnackBar(
        content: Text("You need to accept the terms of use & privacy policy"),
        duration: Duration(seconds: 3),
      ));
    }
  }

  forgotPassword({
    @required BuildContext context,
    @required GlobalKey<FormState> forgotPasswordFormKey,
    @required TextEditingController emailInputController,
  }) async {
    if (forgotPasswordFormKey.currentState.validate()) {
      try {
        await FirebaseAuth.instance
            .sendPasswordResetEmail(email: emailInputController.text);
        Navigator.pushNamed(context, '/ /login');
      } catch (e) {
        print("An error occured while trying to send password reset email");
        print(e.message);
      }
    }
  }

  emailVerification({
    @required BuildContext context,
    @required User user,
  }) async {
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          title: Text("You haven't verified your email yet"),
          content: Text("Would you like to send an email verification again?"),
          actions: <Widget>[
            FlatButton(
              child: Text("Cancel"),
              onPressed: () {
                Navigator.of(context).pop();
              },
            ),
            FlatButton(
              child: Text("Accept"),
              onPressed: () async {
                await user.sendEmailVerification().then((value) {
                  Navigator.of(context).pop();
                });
              },
            ),
          ],
        );
      },
    );
  }

  updateUserEmail({
    @required BuildContext context,
    @required GlobalKey<ScaffoldState> scaffoldKey,
    @required GlobalKey<FormState> emailFormKey,
    @required List<TextEditingController> inputControllers,
    @required String userID,
    @required bool isEditingEmail,
    @required widgetParent,
  }) async {
    TextEditingController emailInputController = inputControllers[0];
    TextEditingController confirmEmailInputController = inputControllers[1];

    Navigator.of(context).pop();

    if (emailFormKey.currentState.validate()) {
      if (emailInputController.text == confirmEmailInputController.text) {
        User user = FirebaseAuth.instance.currentUser;

        /*user.reauthenticateWithCredential(EmailAuthProvider.getCredential(
            email: 'email', password: 'password'));*/

        user.updateEmail(emailInputController.text).then((value) {
          FirebaseFirestore.instance.collection("users").doc(userID).update({
            "email": emailInputController.text,
          }).then((result) async {
            try {
              await user.sendEmailVerification();
            } catch (e) {
              print("An error occured while trying to send email verification");
              print(e.message);
            }

            isEditingEmail = false;

            widgetParent.setState(() {});

            scaffoldKey.currentState.showSnackBar(SnackBar(
              content: Text("User info saved"),
              duration: Duration(seconds: 3),
            ));
          }).catchError((err) => print(err));
        });
      } else {
        ShowCustomDialog()
            .simple(context, "The emails do not match", "Error", "Close");
      }
    }
  }

  updateUserPassword({
    @required BuildContext context,
    @required GlobalKey<ScaffoldState> scaffoldKey,
    @required GlobalKey<FormState> passwordFormKey,
    @required List<TextEditingController> inputControllers,
    @required String userID,
    @required bool isEditingPassword,
    @required widgetParent,
  }) async {
    TextEditingController passwordInputController = inputControllers[0];
    TextEditingController confirmPasswordInputController = inputControllers[1];

    Navigator.of(context).pop();

    if (passwordFormKey.currentState.validate()) {
      if (passwordInputController.text == confirmPasswordInputController.text) {
        User user = FirebaseAuth.instance.currentUser;

        user.updatePassword(passwordInputController.text).then((_) {
          print("Succesfull changed password");

          isEditingPassword = false;

          widgetParent.setState(() {});

          scaffoldKey.currentState.showSnackBar(SnackBar(
            content: Text("User info saved"),
            duration: Duration(seconds: 3),
          ));
        }).catchError((error) {
          print("Password can't be changed" + error.toString());
        });
      } else {
        ShowCustomDialog()
            .simple(context, "The passwords do not match", "Error", "Close");
      }
    }
  }

  updateUserNameAndInfo({
    @required BuildContext context,
    @required GlobalKey<ScaffoldState> scaffoldKey,
    @required GlobalKey<FormState> nameAndInfoFormKey,
    @required List<TextEditingController> inputControllers,
    @required DateTime selectedDate,
    @required String genderValue,
    @required String countryValue,
    @required String userID,
    @required bool isEditingNameAndInfo,
    @required widgetParent,
  }) {
    TextEditingController firstNameInputController = inputControllers[0];
    TextEditingController lastNameInputController = inputControllers[1];

    Timestamp birthdayTimestamp = Timestamp.fromDate(selectedDate);

    Navigator.of(context).pop();

    if (nameAndInfoFormKey.currentState.validate()) {
      FirebaseFirestore.instance.collection("users").doc(userID).update({
        "firstname": firstNameInputController.text,
        "lastname": lastNameInputController.text,
        "birthday": birthdayTimestamp,
        "gender": genderValue,
        "country": countryValue,
      }).then((result) {
        isEditingNameAndInfo = false;

        widgetParent.setState(() {});

        scaffoldKey.currentState.showSnackBar(SnackBar(
          content: Text("User info saved"),
          duration: Duration(seconds: 3),
        ));
      }).catchError((err) => print(err));
    }
  }
}
